@@ -1,7 +1,7 @@
 package MooseX::MethodAttributes::Role::Meta::Role::Application;
 # ABSTRACT: generic role for applying a role with method attributes to something
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 use Moose::Role;
 use Moose::Util qw/find_meta/;
@@ -68,7 +68,7 @@ MooseX::MethodAttributes::Role::Meta::Role::Application - generic role for apply
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 METHODS
 
@@ -88,7 +88,7 @@ There is also a mailing list available for users of this distribution, at
 L<http://lists.perl.org/list/moose.html>.
 
 There is also an irc channel available for users of this distribution, at
-irc://irc.perl.org/#moose.
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
 
 =head1 AUTHORS
 
